@@ -33,7 +33,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)envelope.c	8.34 (Berkeley) 4/14/94";
+static char sccsid[] = "@(#)envelope.c	8.34.1.1 (Berkeley) 2/28/95";
 #endif /* not lint */
 
 #include "sendmail.h"
@@ -489,7 +489,7 @@ openxscript(e)
 		if (fd < 0)
 			syserr("!Can't open /dev/null");
 	}
-	e->e_xfp = fdopen(fd, "w");
+	e->e_xfp = fdopen(fd, "a");
 	if (e->e_xfp == NULL)
 	{
 		syserr("!Can't create transcript stream %s", p);
